@@ -3,7 +3,8 @@ from collections import OrderedDict, defaultdict
 
 from django.contrib.contenttypes.fields import GenericRelation
 from django.contrib.contenttypes.models import ContentType
-from django.db.models import ProtectedError, FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
+from django.db.models import ProtectedError
 from django.db.models.fields.related import ForeignObjectRel
 from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
